@@ -316,7 +316,7 @@ PARAM_SIMPLE(
 	/* type */	bytes_u,
 	/* min */	"128b",
 	/* max */	"99999999b",
-	/* def */	"48k",
+	/* def */	"64k",
 	/* units */	"bytes",
 	/* descr */
 	"Maximum size of CLI response.  If the response exceeds this "
@@ -332,8 +332,19 @@ PARAM_SIMPLE(
 	/* def */	"60.000",
 	/* units */	"seconds",
 	/* descr */
-	"Timeout for the child's replies to CLI requests from the "
-	"mgt_param."
+	"Timeout for the child's replies to CLI requests."
+)
+
+PARAM_SIMPLE(
+	/* name */	startup_timeout,
+	/* type */	timeout,
+	/* min */	"0.000",
+	/* max */	NULL,
+	/* def */	"0.000",
+	/* units */	"seconds",
+	/* descr */
+	"Alternative timeout for the initial worker process startup.\n"
+	"If cli_timeout is longer than startup_timeout, it is used instead."
 )
 
 PARAM_SIMPLE(
@@ -448,7 +459,10 @@ PARAM_SIMPLE(
 	/* descr */
 	"Number of io vectors to allocate for HTTP1 protocol transmission."
 	"  A HTTP1 header needs 7 + 2 per HTTP header field."
-	"  Allocated from workspace_thread.",
+	"  Allocated from workspace_thread."
+	"  This parameter affects only io vectors used for client delivery."
+	"  For backend fetches, the maximum number of io vectors (up to IOV_MAX)"
+	"  is allocated from available workspace_thread memory.",
 	/* flags */	WIZARD
 )
 
@@ -952,6 +966,31 @@ PARAM_SIMPLE(
 	/* flags */	EXPERIMENTAL
 )
 
+PARAM_SIMPLE(
+	/* name */	transit_buffer,
+	/* type */	bytes,
+	/* min */	"0k",
+	/* max */	NULL,
+	/* def */	"0k",
+	/* units */	"bytes",
+	/* descr */
+
+	"The number of bytes which Varnish buffers for uncacheable "
+	"backend streaming fetches - in other words, how many bytes "
+	"Varnish reads from the backend ahead of what has been sent to "
+	"the client.\n"
+	"A zero value means no limit, the object is fetched as fast as "
+	"possible.\n\n"
+	"When dealing with slow clients, setting this parameter to "
+	"non-zero can prevent large uncacheable objects from being "
+	"stored in full when the intent is to simply stream them to the "
+	"client. As a result, a slow client transaction holds onto a "
+	"backend connection until the end of the delivery.\n\n"
+	"This parameter is the default to the VCL variable "
+	"``beresp.transit_buffer``, which can be used to control the "
+	"transit buffer per backend request."
+)
+
 PARAM_SIMPLE(
 	/* name */	vary_notice,
 	/* type */	uint,
@@ -1218,6 +1257,52 @@ PARAM_SIMPLE(
 	"HTTP2 maximum size of an uncompressed header list."
 )
 
+#define H2_RR_INFO \
+	"Changes to this parameter affect the default for new HTTP2 " \
+	"sessions. vmod_h2(3) can be used to adjust it from VCL."
+
+PARAM_SIMPLE(
+	/* name */	h2_rapid_reset,
+	/* typ */	timeout,
+	/* min */	"0.000",
+	/* max */	NULL,
+	/* def */	"1.000",
+	/* units */	"seconds",
+	/* descr */
+	"The upper threshold for how soon an http/2 RST_STREAM frame has "
+	"to be parsed after a HEADERS frame for it to be treated as "
+	"suspect and subjected to the rate limits specified by "
+	"h2_rapid_reset_limit and h2_rapid_reset_period.\n" H2_RR_INFO,
+	/* flags */	EXPERIMENTAL|DELAYED_EFFECT,
+)
+
+PARAM_SIMPLE(
+	/* name */	h2_rapid_reset_limit,
+	/* typ */	uint,
+	/* min */	"0",
+	/* max */	NULL,
+	/* def */	"100",
+	/* units */	NULL,
+	/* descr */
+	"HTTP2 RST Allowance.\n"
+	"Specifies the maximum number of allowed stream resets issued by\n"
+	"a client over a time period before the connection is closed.\n"
+	"Setting this parameter to 0 disables the limit.\n" H2_RR_INFO,
+	/* flags */	EXPERIMENTAL|DELAYED_EFFECT,
+)
+
+PARAM_SIMPLE(
+	/* name */	h2_rapid_reset_period,
+	/* typ */	timeout,
+	/* min */	"1.000",
+	/* max */	NULL,
+	/* def */	"60.000",
+	/* units */	"seconds",
+	/* descr */
+	"HTTP2 sliding window duration for h2_rapid_reset_limit.\n" H2_RR_INFO,
+	/* flags */	EXPERIMENTAL|DELAYED_EFFECT|WIZARD,
+)
+
 /*--------------------------------------------------------------------
  * Memory pool parameters
  */
@@ -1743,7 +1828,9 @@ PARAM_PRE
 PARAM_BITS(
 	/* name */	feature,
 	/* fld */	feature_bits,
-	/* def */	"+validate_headers",
+	/* def */
+	"+validate_headers,"
+	"+vcl_req_reset",
 	/* descr */
 	"Enable/Disable various minor features.\n"
 	"\tdefault\tSet default value\n"
@@ -1789,7 +1876,6 @@ PARAM_BITS(
 	"-ObjProtocol,"
 	"-ObjReason,"
 	"-ObjStatus,"
-	"-VCL_trace,"
 	"-VdpAcct,"
 	"-VfpAcct,"
 	"-WorkThread",
